import SwiftUI

struct LocalizedTagDetailView: View {

    @Binding
    var tagIsVisible: Bool

    @ObservedObject
    var tag: LocalizedTag

    @EnvironmentObject
    private var content: Content

    @State
    private var showImagePicker = false

    var body: some View {
        ScrollView {
            VStack(alignment: .leading) {
                Toggle("Appears in overviews", isOn: $tagIsVisible)
                    .toggleStyle(.switch)
                    .font(.headline)
                    .padding(.bottom)

                Text("Name")
                    .font(.headline)
                TextField("", text: $tag.name)
                    .textFieldStyle(.roundedBorder)
                    .padding(.bottom)

                Text("URL String")
                    .font(.headline)
                TextField("", text: $tag.urlComponent)
                    .textFieldStyle(.roundedBorder)
                    .padding(.bottom)

                Text("Original url")
                    .font(.headline)
                Text(tag.originalUrl ?? "-")
                    .padding(.top, 1)
                    .padding(.bottom)

                Text("Subtitle")
                    .font(.headline)
                OptionalTextField("", text: $tag.subtitle)
                    .textFieldStyle(.roundedBorder)
                    .padding(.bottom)

                Text("Link Preview Description")
                    .font(.headline)
                    .padding(.top)
                OptionalDescriptionField(text: $tag.description)
                    .textFieldStyle(.roundedBorder)
                    .padding(.bottom)

                HStack {
                    Text("Link Preview Image")
                        .font(.headline)
                    IconButton(symbol: .squareAndPencilCircleFill,
                               size: 22,
                               color: .blue) {
                        showImagePicker = true
                    }

                    IconButton(symbol: .trashCircleFill,
                               size: 22,
                               color: .red) {
                        tag.linkPreviewImage = nil
                    }.disabled(tag.linkPreviewImage == nil)
                    Spacer()
                }

                .buttonStyle(.plain)
                if let image = tag.linkPreviewImage {
                    image.imageToDisplay
                        .resizable()
                        .aspectRatio(contentMode: .fit)
                        .frame(maxWidth: 400, maxHeight: 300)
                        .cornerRadius(8)
                }
            }
            .padding()
        }
        .sheet(isPresented: $showImagePicker) {
            ImagePickerView(showImagePicker: $showImagePicker) { image in
                tag.linkPreviewImage = image
            }
        }
    }
}

#Preview {
    LocalizedTagDetailView(
        tagIsVisible: .constant(true),
        tag: Tag.mock.english)
}
